<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk" sourcelanguage="en_US">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="363"/>
        <source>Learn Basic Operations</source>
        <translation>Вивчення основних дій</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="366"/>
        <source>Common Application Libraries</source>
        <translation>Загальні бібліотеки програм</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="369"/>
        <source>Desktop Environment</source>
        <translation>Стільничне середовище</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="291"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>Шукати «%1» у всьому тексті</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="363"/>
        <source>The content was updated</source>
        <translation>Дані було оновлено</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="767"/>
        <source>Search</source>
        <translation>Шукати</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <location filename="../src/view/web_window.cpp" line="771"/>
        <source>Support</source>
        <translation>Підтримка</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="1038"/>
        <source>Copy</source>
        <translation>Копіювати</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>Quick Start</source>
        <translation>Короткий довідник</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Video Guide</source>
        <translation>Відеопідручник</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Applications</source>
        <translation>Програми</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>No search results</source>
        <translation>Нічого не знайдено</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>Home</source>
        <translation>Домівка</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  result</source>
        <translation>результат</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>  results</source>
        <translation>результатів</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
        <source>Click to view </source>
        <translation>Натисніть, щоб переглянути</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>View all</source>
        <translation>Переглянути усе</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
        <source>App Store</source>
        <translation>Крамниця програм</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="136"/>
        <source>Manual</source>
        <translation>Підручник</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="137"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>«Підручник» створено для того, щоб допомогти користувачам, які вивчають операційну систему та її програми. За допомогою цієї програми ви знайдете специфічні настанови та описи функціональних можливостей.</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="952"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="969"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
